#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_IS_NLEZ_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_IS_NLEZ_HPP_INCLUDED

#include <boost/simd/predicates/include/functions/simd/is_nlez.hpp>

#endif
